# Janus

In ancient Roman religion and myth, Janus ( JAY-nəs; Latin: Ianvs [ˈi̯aːnʊs]) is the god of beginnings, gates, transitions, time, duality, doorways, passages, frames, and endings. He is usually depicted as having two faces. The month of January is named for Janus (Ianuarius). Janus presided over the beginning and ending of conflict, and hence war and peace. 

